@@ -810,6 +810,7 @@ int help(int exitcode) {
             "  -W unittest              Run internal unittests and exit.\n\n"
             "  -W sqlite-meta-recover   Run recovery on the metadata database and exit.\n\n"
             "  -W sqlite-compact        Reclaim metadata database unused space and exit.\n\n"
+            "  -W sqlite-analyze        Run update statistics and exit.\n\n"
 #ifdef ENABLE_DBENGINE
             "  -W createdataset=N       Create a DB engine dataset of N seconds and exit.\n\n"
             "  -W stresstest=A,B,C,D,E,F,G\n"
@@ -1516,6 +1517,11 @@ int main(int argc, char **argv) {
                             return 0;
                         }
 
+                        if(strcmp(optarg, "sqlite-analyze") == 0) {
+                            sql_init_database(DB_CHECK_ANALYZE, 0);
+                            return 0;
+                        }
+
                         if(strcmp(optarg, "unittest") == 0) {
                             unittest_running = true;
 
@@ -2002,11 +2008,11 @@ int main(int argc, char **argv) {
         set_silencers_filename();
         health_initialize_global_silencers();
 
-        // --------------------------------------------------------------------
-        // Initialize ML configuration
-
-        delta_startup_time("initialize ML");
-        ml_init();
+//        // --------------------------------------------------------------------
+//        // Initialize ML configuration
+//
+//        delta_startup_time("initialize ML");
+//        ml_init();
 
         // --------------------------------------------------------------------
         // setup process signals
@@ -2059,8 +2065,18 @@ int main(int argc, char **argv) {
         web_client_api_v1_init();
         web_server_threading_selection();
 
-        if(web_server_mode != WEB_SERVER_MODE_NONE)
-            api_listen_sockets_setup();
+        if(web_server_mode != WEB_SERVER_MODE_NONE) {
+            if (!api_listen_sockets_setup()) {
+                netdata_log_error("Cannot setup listen port(s). Is Netdata already running?");
+                exit(1);
+            }
+        }
+
+        // --------------------------------------------------------------------
+        // Initialize ML configuration
+
+        delta_startup_time("initialize ML");
+        ml_init();
 
 #ifdef ENABLE_H2O
         delta_startup_time("initialize h2o server");
