@@ -27,7 +27,7 @@ struct page_descr_with_data {
     uint8_t type;
     uint32_t update_every_s;
     uint32_t page_length;
-    uint8_t *page;
+    struct pgd *pgd;
 
     struct {
         struct page_descr_with_data *prev;
@@ -45,16 +45,14 @@ struct rrdeng_page_info {
 };
 
 struct pg_alignment {
-    uint32_t page_position;
     uint32_t refcount;
-    uint16_t initial_slots;
 };
 
 struct rrdeng_query_handle;
 struct page_details_control;
 
 void rrdeng_prep_wait(struct page_details_control *pdc);
-void rrdeng_prep_query(struct page_details_control *pdc);
+void rrdeng_prep_query(struct page_details_control *pdc, bool worker);
 void pg_cache_preload(struct rrdeng_query_handle *handle);
 struct pgc_page *pg_cache_lookup_next(struct rrdengine_instance *ctx, struct page_details_control *pdc, time_t now_s, time_t last_update_every_s, size_t *entries);
 void pgc_and_mrg_initialize(void);
